/******************************************************************************/
/* User Level #define Macros                                                  */
/******************************************************************************/

/*--------------------------------ADC CHANNELS--------------------------------*/
#define AUD_IN		0b00110
#define SENSE_R		0b00000
#define SENSE_G		0b00001
#define SENSE_B		0b00011
#define TEMP_IND	0b11101
/*----------------------------------------------------------------------------*/

#define TEMP_OFFSET	0x23
#define TEMP_COEF	-0.00022//TC: -2,2mV/C
#define	V_OPEN_DRAN	0.666	//@ 24C
#define V_FAULT		45	//150mV @ 10A

#define START_C	0b00001000	//START CONDITION MASK
#define STOP_C	0b00010000	//STOP CONDITION MASK
#define STATE1	0b00001001	// MASTER WRITE LAST WAS ADDRESS
#define STATE2	0b00101001	// MASTER WRITE LAST WAS DATA
#define STATE3	0b00001101	// MASTER READ LAST WAS ADDRESS
#define STATE4	0b00101100	// MASTER READ LAST WAS DATA
#define STATE5	0b00101000	// MASTER NACK

#define MAX_BUFFER_SIZE		10

#define DMX_START_CODE		0x00
#define DMX_TRIS		TRISAbits.TRISA5
#define DMX_LAT			LATAbits.LATA5
#define DMX_PORT		PORTAbits.RA5

#define DEFAULT_ADDRESS		0x20
#define MEMORY_ADDRESS		0x7FF
#define DMX_ADDRESS		0x7FE

#define TRIS_R			TRISCbits.TRISC5
#define TRIS_G			TRISCbits.TRISC3
#define TRIS_B			TRISAbits.TRISA2
#define LAT_R			LATCbits.LATC5
#define LAT_G			LATCbits.LATC3
#define LAT_B			LATAbits.LATA2
#define PORT_R			PORTCbits.RC5
#define PORT_G			PORTCbits.RC3
#define PORT_B			PORTAbits.RA2

/*--------------------------------I2C PINS--------------------------------*/
#define SCL_TRIS		TRISCbits.TRISC0
#define SCL_LAT			LATCbits.LATC0
#define SCL_PORT		PORTCbits.RC0
#define SDA_TRIS		TRISCbits.TRISC1
#define SDA_LAT			LATCbits.LATC1
#define SDA_PORT		PORTCbits.RC1

#define DMX_EN_TRIS		TRISCbits.TRISC4
#define DMX_EN_LAT		LATCbits.LATC4
#define DMX_EN_PORT		PORTCbits.RC4
/*----------------------------------------------------------------------------*/

#define Nop()			asm("nop")



/******************************************************************************/
/* User Function Prototypes                                                   */
/******************************************************************************/
extern unsigned char DATA_BUFFER[6];
extern unsigned char DATA_OUT[2];
extern unsigned int DATA_INDEX;
extern unsigned int AUDIO_FLAG;
extern unsigned char FADE_FLAG;
extern unsigned char DMX_FLAG;
extern unsigned char FADE_SPEED;
extern unsigned char ADDRESS;
extern unsigned char BREAK;
extern unsigned char PORT_STATE;
extern unsigned char TIMER1_STATE;
extern unsigned char _R;
extern unsigned char _G;
extern unsigned char _B;
extern signed int TEMPERATURE;
extern unsigned int REFERENCE;


int ReadFlash(int address);
void EraseFlash(int address);
void UnlockFlash(void);
void WriteFlash(int data, int address);

void InitApp(void);         
void InitGPIO(void);
void InitInterupts(void);
void InitAddress(void);
void InitI2C(void);
void InitADC(void);
void InitPWM(void);
void InitTimer(void);
void InitTemperatureSensor(void);
unsigned char JumperIsOpen(void);

void StartPWM(void);
void StopPWM(void);
void SetPWM(unsigned char R, unsigned char G, unsigned char B);
void SetAddress(unsigned char addr);

void Fade(void);
void StartDMX(void);
void Delay(unsigned char delay);
void GetTemperature(void);

/* I2C-MASTER ROUTINES */
void WaitSSP(void);
void StartI2C(void);
void StopI2C(void);
char I2CSendByte(unsigned char data);
